==> Resourcerer_1.24.0.zip: Resourcerer/doc/Resourcerer.R <==
###################################################
### chunk number 1: 
###################################################
#line 41 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpuLc98g/R.INSTALL4f536158/Resourcerer/inst/doc/Resourcerer.Rnw"
require("AnnotationDbi", quietly = TRUE)
require("Resourcerer", quietly = TRUE)


###################################################
### chunk number 2: 
###################################################
#line 57 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpuLc98g/R.INSTALL4f536158/Resourcerer/inst/doc/Resourcerer.Rnw"
agilent <- getResourcerer("Agilent_Human1_cDNA.zip", organism = "human",
destDir = file.path(.path.package("Resourcerer"), "temp"), baseUrl =
            "ftp://occams.dfci.harvard.edu/pub/bio/tgi/data/Resourcerer",
            clean = TRUE )


###################################################
### chunk number 3: 
###################################################
#line 70 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpuLc98g/R.INSTALL4f536158/Resourcerer/inst/doc/Resourcerer.Rnw"
agilent[1:5, 1:4]


###################################################
### chunk number 4: 
###################################################
#line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpuLc98g/R.INSTALL4f536158/Resourcerer/inst/doc/Resourcerer.Rnw"
as.vector(colnames(agilent))


###################################################
### chunk number 5: 
###################################################
#line 95 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpuLc98g/R.INSTALL4f536158/Resourcerer/inst/doc/Resourcerer.Rnw"

if(interactive()) {
    resourcerer2BioC("Agilent_Human1_cDNA.zip", organism = "human",
       destDir =  file.path(.path.package("Resourcerer"), "temp"),
       pkgName = "AgilentHsa1",
       srcUrls = getSrcUrl("all", "Homo sapiens"),
       pkgPath =  file.path(.path.package("Resourcerer"), "temp"),
       otherSrc = NULL, baseMapType = "gb",
       version = "1.1.0", fromWeb = TRUE,
       baseUrl = "ftp://occams.dfci.harvard.edu/pub/bio/tgi/data/Resourcerer",
               check = TRUE, author = list(authors = "Anonymous",
                              maintainer = "Anonymous <anonimous@email.com>"))
   }else{
       print("Code is executed only when invoked interactively")
   }

==> Resourcerer_1.26.0.zip: Resourcerer/doc/Resourcerer.R <==
###################################################
### chunk number 1: 
###################################################
#line 41 "Resourcerer.Rnw"
require("AnnotationDbi", quietly = TRUE)
require("Resourcerer", quietly = TRUE)


###################################################
### chunk number 2: 
###################################################
#line 57 "Resourcerer.Rnw"
agilent <- getResourcerer("Agilent_Human1_cDNA.zip", organism = "human",
destDir = file.path(.path.package("Resourcerer"), "temp"), baseUrl =
            "ftp://occams.dfci.harvard.edu/pub/bio/tgi/data/Resourcerer",
            clean = TRUE )


###################################################
### chunk number 3: 
###################################################
#line 70 "Resourcerer.Rnw"
agilent[1:5, 1:4]


###################################################
### chunk number 4: 
###################################################
#line 76 "Resourcerer.Rnw"
as.vector(colnames(agilent))


###################################################
### chunk number 5: 
###################################################
#line 95 "Resourcerer.Rnw"

if(interactive()) {
    resourcerer2BioC("Agilent_Human1_cDNA.zip", organism = "human",
       destDir =  file.path(.path.package("Resourcerer"), "temp"),
       pkgName = "AgilentHsa1",
       srcUrls = getSrcUrl("all", "Homo sapiens"),
       pkgPath =  file.path(.path.package("Resourcerer"), "temp"),
       otherSrc = NULL, baseMapType = "gb",
       version = "1.1.0", fromWeb = TRUE,
       baseUrl = "ftp://occams.dfci.harvard.edu/pub/bio/tgi/data/Resourcerer",
               check = TRUE, author = list(authors = "Anonymous",
                              maintainer = "Anonymous <anonimous@email.com>"))
   }else{
       print("Code is executed only when invoked interactively")
   }
